| Title: | Genetics Genome Browser |
|---|---|
| Description: | Plot genome scan results with the Genetics Genome Browser: fast, lightweight, powered by purescript. |
| Authors: | Karl W Broman [aut, cre]
|
| Maintainer: | Karl W Broman <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1-1 |
| Built: | 2026-06-03 13:22:38 UTC |
| Source: | https://github.com/rqtl/qtl2browse |
Use the genetics genome browser to browse QTL mapping results
browse(scan1output, map, lodcolumn = 1, min_lod = 0, dir = NULL)browse(scan1output, map, lodcolumn = 1, min_lod = 0, dir = NULL)
scan1output |
Genome scan output, as from |
map |
Corresponding physical map (in Mbp), as a list of
chromosomes that are each a vector of marker positions. Can
also be a data frame of SNP information, with columns |
lodcolumn |
LOD score column to plot (a numeric index, or a character string for a column name). Only one value allowed. |
min_lod |
Minimum LOD score to show; values below this are omitted. |
dir |
Optional directory to contain the results. If not provided, a temporary directory is created. |
File location (hidden).
library(qtl2) recla <- read_cross2(paste0("https://raw.githubusercontent.com/rqtl/", "qtl2data/master/DO_Recla/recla.zip")) gmap <- insert_pseudomarkers(recla$gmap, step=0.2, stepwidth="max") pmap <- interp_map(gmap, recla$gmap, recla$pmap) pr <- calc_genoprob(recla, gmap, error_prob=0.002, map_function="c-f", cores=0) apr <- genoprob_to_alleleprob(pr) k <- calc_kinship(apr, "loco", cores=0) out <- scan1(apr, recla$pheno[,"HP_latency"], k, cores=0) library(qtl2browse) browse(out, pmap)library(qtl2) recla <- read_cross2(paste0("https://raw.githubusercontent.com/rqtl/", "qtl2data/master/DO_Recla/recla.zip")) gmap <- insert_pseudomarkers(recla$gmap, step=0.2, stepwidth="max") pmap <- interp_map(gmap, recla$gmap, recla$pmap) pr <- calc_genoprob(recla, gmap, error_prob=0.002, map_function="c-f", cores=0) apr <- genoprob_to_alleleprob(pr) k <- calc_kinship(apr, "loco", cores=0) out <- scan1(apr, recla$pheno[,"HP_latency"], k, cores=0) library(qtl2browse) browse(out, pmap)